package org.ow2.bonita.connector;

/**
 * Describes what kind of Exception were raised on a field.
 * @author chaffotm
 *
 */
public class ConnectorError {

  /**
   * The field name.
   */
  private String field;

  /**
   * The exception description.
   */
  private Exception error;

  /**
   * Default constructor.
   * @param field the field name
   * @param error the field exception
   */
  public ConnectorError(final String field, final Exception error) {
    this.field = field;
    this.error = error;
  }

  /**
   * Returns the field name.
   * @return the field name
   */
  public final String getField() {
    return field;
  }

  /**
   * Returns the field exception.
   * @return the the field exception
   */
  public final Exception getError() {
    return error;
  }

  /**
   * Compares this object against the specified object. The result is true
   * if and only if the argument represents the same ConnectorError as this
   * object.
   * @param obj the object to compare against.
   * @return if the objects are the same; false otherwise.
   */
  @Override
  public boolean equals(final Object obj) {
    boolean equals = false;
    if (obj instanceof ConnectorError) {
      ConnectorError c = (ConnectorError) obj;
      if (this.getField().equals(c.getField())
          && this.getError().getMessage().equals(c.getError().getMessage())) {
        equals = true;
      }
    }
    return equals;
  }
}
