package org.ow2.bonita.connector.util;

import java.util.ArrayList;
import java.util.List;

import org.ow2.bonita.connector.Connector;
import org.ow2.bonita.connector.ConnectorError;
import org.ow2.bonita.connector.annotation.Input;
import org.ow2.bonita.connector.annotation.Output;
import org.ow2.bonita.connector.annotation.Required;

public class SubStringStringConnector extends Connector {

  private String string;
  private Integer beginIndex;
  private Integer endIndex;
  private String result;
  
  public String getString() {
    return string;
  }

  public Integer getBeginIndex() {
    return beginIndex;
  }

  public Integer getEndIndex() {
    return endIndex;
  }

  @Output
  public String getResult() {
    return result;
  }

  @Input @Required
  public void setString(String string) {
    this.string = string;
  }

  @Input @Required
  public void setBeginIndex(int beginIndex) {
    this.beginIndex = beginIndex;
  }
  
  public void setBeginIndex(Long beginIndex) {
    if (beginIndex == null) {
      this.beginIndex = null;
    } else {
      this.beginIndex = beginIndex.intValue();
    }
  }

  @Input
  public void setEndIndex(int endIndex) {
    this.endIndex = endIndex;
  }
  
  public void setEndIndex(Long endIndex) {
    if (endIndex == null) {
      this.endIndex = null;
    } else {
      this.endIndex = endIndex.intValue();
    }
  }

  public void setResult(String result) {
    this.result = result;
  }

  @Override
  protected void executeConnector() throws Exception {
    if (getEndIndex() == null) {
      result = string.substring(beginIndex);
    } else {
      result = string.substring(beginIndex, endIndex);
    }
  }

  @Override
  protected List<ConnectorError> validateValues() {
    List<ConnectorError> errors = new ArrayList<ConnectorError>();
    if (getBeginIndex() < 0) {
      errors.add(new ConnectorError("beginIndex",
          new IllegalArgumentException("cannot be negative")));
    } else if (getBeginIndex() > getString().length()){
      errors.add(new ConnectorError("beginIndex",
          new IllegalArgumentException("cannot be greater than the String lenght!")));
    }
    if (getEndIndex() != null) {
      if (getEndIndex() < 0) {
        errors.add(new ConnectorError("endIndex",
            new IllegalArgumentException("cannot be negative")));
      } else {
        if (getEndIndex() > getString().length()){
          errors.add(new ConnectorError("endIndex",
              new IllegalArgumentException("cannot be greater than the String lenght!")));
        }
        if (getBeginIndex() > getEndIndex()) {
          errors.add(new ConnectorError("beginIndex",
              new IllegalArgumentException("cannot be greater than the endIndex!")));
        }
      }
    }
    return errors;
  }
}
